@@ -15,10 +15,10 @@ import warnings
 
 from collections.abc import Iterable
 
+import hypothesis
 import pytest
 
 from coverage.files import set_relative_directory
-from coverage.patch import create_pth_files
 
 from tests import testenv
 
@@ -35,6 +35,14 @@ pytest_plugins = [
     "tests.select_plugin",
 ]
 
+# Control the Hypothesis settings.
+# $set_env.py: HYPOTHESIS_PROFILE - "slow": 25k examples; "250k"
+hypothesis.settings.register_profile("slow", max_examples=25_000)
+hypothesis.settings.register_profile("250k", max_examples=250_000)
+# In CI, using the database makes the first draw take more than a second.
+hypothesis.settings.register_profile("ci", database=None, max_examples=1000)
+hypothesis.settings.load_profile(os.getenv("HYPOTHESIS_PROFILE", "default"))
+
 
 @pytest.fixture(autouse=True)
 def set_warnings() -> None:
@@ -64,7 +72,7 @@ def set_warnings() -> None:
 
     # For when our own tests can't use sysmon though it was requested.
     warnings.filterwarnings("ignore", r".*no-sysmon")
-    if testenv.REQUESTED_CORE != "ctrace":
+    if testenv.CORE != "ctrace":
         warnings.filterwarnings("ignore", r".*no-ctracer")
 
 
@@ -97,15 +105,3 @@ def force_local_pyc_files() -> None:
     # For some tests, we need .pyc files written in the current directory,
     # so override any local setting.
     sys.pycache_prefix = None
-
-
-# Give this an underscored name so pylint won't complain when we use the fixture.
-@pytest.fixture(name="_create_pth_file")
-def create_pth_file_fixture() -> Iterable[None]:
-    """Create and clean up a .pth file for tests that need it for subprocesses."""
-    pth_files = create_pth_files()
-    try:
-        yield
-    finally:
-        for p in pth_files:
-            p.unlink()
