@@ -1,11 +1,12 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
-# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
+# For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt
 
 """Tests for coverage.py's arc measurement."""
 
 from __future__ import annotations
 
 import textwrap
+from unittest import mock
 
 import pytest
 
@@ -13,6 +14,8 @@ from tests.coveragetest import CoverageTest
 from tests.helpers import assert_count_equal
 
 import coverage
+import coverage.python
+from coverage import env
 from coverage.data import sorted_lines
 from coverage.files import abs_file
 
@@ -269,7 +272,7 @@ class WithTest(CoverageTest):
         )
 
     def test_bug_146(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/146
+        # https://github.com/coveragepy/coveragepy/issues/146
         self.check_coverage(
             """\
             for i in range(2):
@@ -325,7 +328,7 @@ class WithTest(CoverageTest):
             branchz_missing="",
         )
 
-    # https://github.com/nedbat/coveragepy/issues/1270
+    # https://github.com/coveragepy/coveragepy/issues/1270
     def test_raise_through_with(self) -> None:
         cov = self.check_coverage(
             """\
@@ -414,7 +417,7 @@ class WithTest(CoverageTest):
         )
 
     def test_multiline_with(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/1880
+        # https://github.com/coveragepy/coveragepy/issues/1880
         self.check_coverage(
             """\
             import contextlib, itertools
@@ -431,7 +434,7 @@ class WithTest(CoverageTest):
         )
 
     def test_multi_multiline_with(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/1880
+        # https://github.com/coveragepy/coveragepy/issues/1880
         self.check_coverage(
             """\
             import contextlib, itertools
@@ -450,7 +453,7 @@ class WithTest(CoverageTest):
         )
 
     def test_multi_multiline_with_backslash(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/1880
+        # https://github.com/coveragepy/coveragepy/issues/1880
         self.check_coverage(
             """\
             import contextlib, itertools
@@ -620,7 +623,7 @@ class LoopArcTest(CoverageTest):
         )
 
     def test_zero_coverage_while_loop(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/502
+        # https://github.com/coveragepy/coveragepy/issues/502
         self.make_file("main.py", "print('done')")
         self.make_file(
             "zero.py",
@@ -639,7 +642,7 @@ class LoopArcTest(CoverageTest):
         assert expected in squeezed[3]
 
     def test_bug_496_continue_in_constant_while(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/496
+        # https://github.com/coveragepy/coveragepy/issues/496
         self.check_coverage(
             """\
             up = iter('ta')
@@ -1378,6 +1381,36 @@ class ExceptionArcTest(CoverageTest):
             branchz_missing="",
         )
 
+    @pytest.mark.skipif(env.PYVERSION < (3, 11), reason="ExceptionGroup is new in Python 3.11")
+    def test_exception_group(self) -> None:
+        # PyPy3.11 traces this incorrectly: https://github.com/pypy/pypy/issues/5354
+        if env.PYPY:
+            missing = "5, 11"
+        else:
+            missing = "5-6, 11-12"
+        self.check_coverage(
+            """\
+            a = 1
+            try:
+                raise ExceptionGroup("Zero!", [ZeroDivisionError()])
+            except* ValueError:
+                a = 5
+                b = 6/0
+            except* ZeroDivisionError:
+                a = 8
+                b = 9
+            except* Exception:
+                a = 11
+                b = 12/0
+            assert a == 8
+            assert b == 9
+            """,
+            lines=[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
+            missing=missing,
+            branchz="",
+            branchz_missing="",
+        )
+
 
 class YieldTest(CoverageTest):
     """Arc tests for generators."""
@@ -1504,7 +1537,7 @@ class YieldTest(CoverageTest):
         )
 
     def test_abandoned_yield(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/440
+        # https://github.com/coveragepy/coveragepy/issues/440
         self.check_coverage(
             """\
             def gen():
@@ -1597,7 +1630,7 @@ class MatchCaseTest(CoverageTest):
         assert self.stdout() == "None\nno go\ngo: n\n"
 
     def test_absurd_wildcards(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/1421
+        # https://github.com/coveragepy/coveragepy/issues/1421
         self.check_coverage(
             """\
             def absurd(x):
@@ -1873,7 +1906,7 @@ class MiscArcTest(CoverageTest):
 
     @pytest.mark.parametrize("n", [10, 50, 100, 500, 1000, 2000, 10000])
     def test_pathologically_long_code_object(self, n: int) -> None:
-        # https://github.com/nedbat/coveragepy/issues/359
+        # https://github.com/coveragepy/coveragepy/issues/359
         # Long code objects sometimes cause problems. Originally, it was
         # due to EXTENDED_ARG bytes codes.  Then it showed a mistake in
         # line-number packing.
@@ -1898,7 +1931,7 @@ class MiscArcTest(CoverageTest):
         assert self.stdout() == f"{n}\n"
 
     def test_partial_generators(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/475
+        # https://github.com/coveragepy/coveragepy/issues/475
         # Line 2 is executed completely.
         # Line 3 is started but not finished, because zip ends before it finishes.
         # Line 4 is never started.
@@ -1916,6 +1949,25 @@ class MiscArcTest(CoverageTest):
             branchz_missing="",
         )
 
+    def test_failing_open(self) -> None:
+        with mock.patch.object(coverage.python, "open", side_effect=IOError("Nope")):
+            self.make_file(
+                "some_branches.py",
+                """\
+                def forelse(seq):
+                    for n in seq:
+                        if n > 5:
+                            break
+                    else:
+                        print('None of the values were greater than 5')
+                    print('Done')
+                forelse([1,2])
+                """,
+            )
+            cov = coverage.Coverage(branch=True)
+            self.start_import_stop(cov, "some_branches")
+            # No assert: the test passes if it didn't raise an exception.
+
 
 class DecoratorArcTest(CoverageTest):
     """Tests of arcs with decorators."""
@@ -2176,7 +2228,7 @@ class AsyncTest(CoverageTest):
             branchz_missing="",
         )
 
-    # https://github.com/nedbat/coveragepy/issues/1158
+    # https://github.com/coveragepy/coveragepy/issues/1158
     def test_bug_1158(self) -> None:
         self.check_coverage(
             """\
@@ -2201,7 +2253,7 @@ class AsyncTest(CoverageTest):
         )
         assert self.stdout() == "14\n"
 
-    # https://github.com/nedbat/coveragepy/issues/1176
+    # https://github.com/coveragepy/coveragepy/issues/1176
     # https://bugs.python.org/issue44622
     def test_bug_1176(self) -> None:
         self.check_coverage(
@@ -2222,7 +2274,7 @@ class AsyncTest(CoverageTest):
         )
         assert self.stdout() == "12\n"
 
-    # https://github.com/nedbat/coveragepy/issues/1205
+    # https://github.com/coveragepy/coveragepy/issues/1205
     def test_bug_1205(self) -> None:
         self.check_coverage(
             """\
@@ -2333,8 +2385,6 @@ class LineDataTest(CoverageTest):
     """Tests that line_data gives us what we expect."""
 
     def test_branch(self) -> None:
-        cov = coverage.Coverage(branch=True)
-
         self.make_file(
             "fun1.py",
             """\
@@ -2346,6 +2396,7 @@ class LineDataTest(CoverageTest):
             """,
         )
 
+        cov = coverage.Coverage(branch=True)
         self.start_import_stop(cov, "fun1")
 
         data = cov.get_data()
