@@ -1,5 +1,5 @@
 # Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
-# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
+# For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt
 
 """Tests for files.py"""
 
@@ -10,7 +10,7 @@ import os
 import os.path
 import re
 
-from typing import Any, Protocol
+from typing import Any
 from collections.abc import Iterable
 from unittest import mock
 
@@ -29,6 +29,7 @@ from coverage.files import (
     flat_rootname,
     globs_to_regex,
 )
+from coverage.types import TMatcher
 
 from tests.coveragetest import CoverageTest
 from tests.helpers import os_sep
@@ -61,7 +62,7 @@ class FilesTest(CoverageTest):
         assert files.relative_filename(a2) == a2
 
     def test_filepath_contains_absolute_prefix_twice(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/194
+        # https://github.com/coveragepy/coveragepy/issues/194
         # Build a path that has two pieces matching the absolute path prefix.
         # Technically, this test doesn't do that on Windows, but drive
         # letters make that impractical to achieve.
@@ -361,13 +362,6 @@ def test_invalid_globs(pattern: str, bad_word: str) -> None:
         globs_to_regex([pattern])
 
 
-class TMatcher(Protocol):
-    """The shape all Matchers have."""
-
-    def match(self, s: str) -> bool:
-        """Does this string match?"""
-
-
 class MatcherTest(CoverageTest):
     """Tests of file matchers."""
 
@@ -606,7 +600,7 @@ class PathAliasesTest(CoverageTest):
 
     @pytest.mark.parametrize("paths", lin_win_paths)
     def test_windows_on_linux(self, paths: Iterable[str], rel_yn: bool) -> None:
-        # https://github.com/nedbat/coveragepy/issues/618
+        # https://github.com/coveragepy/coveragepy/issues/618
         aliases = PathAliases(relative=rel_yn)
         for path in paths:
             aliases.add(path, "project/module")
@@ -618,7 +612,7 @@ class PathAliasesTest(CoverageTest):
 
     @pytest.mark.parametrize("paths", lin_win_paths)
     def test_linux_on_windows(self, paths: Iterable[str], rel_yn: bool) -> None:
-        # https://github.com/nedbat/coveragepy/issues/618
+        # https://github.com/coveragepy/coveragepy/issues/618
         aliases = PathAliases(relative=rel_yn)
         for path in paths:
             aliases.add(path, "project\\module")
@@ -630,7 +624,7 @@ class PathAliasesTest(CoverageTest):
 
     @pytest.mark.parametrize("paths", lin_win_paths)
     def test_relative_windows_on_linux(self, paths: Iterable[str]) -> None:
-        # https://github.com/nedbat/coveragepy/issues/991
+        # https://github.com/coveragepy/coveragepy/issues/991
         aliases = PathAliases(relative=True)
         for path in paths:
             aliases.add(path, "project/module")
@@ -642,7 +636,7 @@ class PathAliasesTest(CoverageTest):
 
     @pytest.mark.parametrize("paths", lin_win_paths)
     def test_relative_linux_on_windows(self, paths: Iterable[str]) -> None:
-        # https://github.com/nedbat/coveragepy/issues/991
+        # https://github.com/coveragepy/coveragepy/issues/991
         aliases = PathAliases(relative=True)
         for path in paths:
             aliases.add(path, r"project\module")
@@ -654,7 +648,7 @@ class PathAliasesTest(CoverageTest):
 
     @pytest.mark.skipif(env.WINDOWS, reason="This test assumes Unix file system")
     def test_implicit_relative_windows_on_linux(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/991
+        # https://github.com/coveragepy/coveragepy/issues/991
         aliases = PathAliases(relative=True)
         self.assert_mapped(
             aliases,
@@ -664,7 +658,7 @@ class PathAliasesTest(CoverageTest):
 
     @pytest.mark.skipif(not env.WINDOWS, reason="This test assumes Windows file system")
     def test_implicit_relative_linux_on_windows(self) -> None:
-        # https://github.com/nedbat/coveragepy/issues/991
+        # https://github.com/coveragepy/coveragepy/issues/991
         aliases = PathAliases(relative=True)
         self.assert_mapped(
             aliases,
